@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use utf8; # filenames can be in utf8
 
@@ -17,6 +17,7 @@ use IPC::Run;
 use Text::ParseWords;
 use Encode;
 use Data::Roundtrip qw/perl2dump no-unicode-escape-permanently/;
+use Cwd::utf8 qw/abs_path cwd/;
 
 sub	new {
 	my $class = $_[0];
@@ -261,10 +262,11 @@ sub	input_pattern {
 	my $whoami = ( caller(0) )[3];
 	my $verbos = $self->verbosity();
 	my ($_pattern, $indir) = @$params;
+	my $indir_need_encode_utf8 = 0;
 	if( ! defined $indir ){
-		$indir = Cwd::cwd;
+		$indir = _my_cwd();
 		if( $verbos > 0 ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : warning, no search dir was specified and using current dir '$indir'.\n" }
-	}
+	} else { $indir_need_encode_utf8 = 1 }
 	my $pattern;
 	# allows for /pattern/modifiers
 	if( $_pattern =~ m!^regex\(/(.*?)/(.*?)\)$! ){
@@ -281,7 +283,7 @@ sub	input_pattern {
 		map { Encode::decode_utf8($_) } File::Find::Rule
 			->file()
 			->name($pattern)
-			->in($indir)
+			->in(Encode::encode_utf8($indir))
 	]) ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : error, call to input_images() has failed.\n"; return 0 }
 
 	return 1 # success
@@ -323,21 +325,37 @@ sub	input_images {
 	if( $rf eq 'ARRAY' ){
 		for my $af (@$m){
 			if( ! -e $af ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : warning/1, input image '$af' does not exist on disk and will be ignored.\n"; next }
-			push @{$self->{'input-images'}}, Encode::decode_utf8(Cwd::abs_path($af));
+			push @{$self->{'input-images'}}, _my_abs_path($af);
 		}
 	} elsif( $rf eq 'HASH' ){
 		for my $af (values %$m){
 			if( ! -e $af ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : warning/2, input image '$af' does not exist on disk and will be ignored.\n"; next }
-			push @{$self->{'input-images'}}, Encode::decode_utf8(Cwd::abs_path($af));
+			push @{$self->{'input-images'}}, _my_abs_path($af);
 		}		
 	} elsif( $rf eq '' ){
 		if( ! -e $m ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : warning/3, input image '$m' does not exist on disk and will be ignored.\n"; }
-		else { push @{$self->{'input-images'}}, Encode::decode_utf8(Cwd::abs_path($m)) }
+		else { push @{$self->{'input-images'}}, _my_abs_path($m) }
 	} else { print STDERR "${whoami} (via $parent), line ".__LINE__." : error, input can be an arrayref of input image filenames, a hashref whose values are filenames or a single filename in the form of a scalar."; return undef }
 	if( $verbos > 1 ){ print STDOUT perl2dump($self->{'input-images'})."${whoami} (via $parent), line ".__LINE__." : called and added some images, above is a list of all input images to create the animation.\n" }
 	return $self->{'input-images'}
 }
 
+sub _my_cwd {
+	return cwd()
+}
+# NOTE: unicode filenames may not be canonicalised
+# e.g. iota-including-accent and iota with separate accent.
+# the OS will not care but if you do comparisons you will fail
+# So, consider canonicalising the filenames if you are doing comparison
+# e.g. in the tests
+# see https://perlmonks.org/?node_id=11156629
+# Also, Cwd needs utf8 decode but Cwd::utf8 doesn't
+# And File::Find::Rule needs also utf8 decoce unless it is chained to abs_path
+sub _my_abs_path {
+	#return Encode::decode_utf8(abs_path($_[0])) # for plain Cwd
+	return abs_path($_[0]) # for Cwd::utf8
+}
+
 # that's the end, pod now starts
 
 =pod
@@ -350,7 +368,7 @@ Automate::Animate::FFmpeg - Create animation from a sequence of images using FFm
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 
 =head1 SYNOPSIS
